@@ -28,7 +28,7 @@
 
 gboolean   gnc_dom_tree_to_owner (xmlNodePtr node, GncOwner *owner,
                                   QofBook *book);
-xmlNodePtr gnc_owner_to_dom_tree (const char *tag, GncOwner *addr);
+xmlNodePtr gnc_owner_to_dom_tree (const char *tag, const GncOwner *addr);
 void gnc_owner_xml_initialize (void);
 
 #endif /* GNC_OWNER_XML_V2_H */
