@@ -274,7 +274,7 @@ gnc_employee_window_cancel_cb (GtkWidget *widget, gpointer data)
 void
 gnc_employee_window_help_cb (GtkWidget *widget, gpointer data)
 {
-    gnc_gnome_help(HF_HELP, HL_USAGE_BSNSS);
+    gnc_gnome_help(HF_HELP, HL_USAGE_EMPLOYEE);
 }
 
 void
